API reference
=============

xbout.boutdataarray module
--------------------------

.. automodule:: xbout.boutdataarray
    :members:
    :undoc-members:
    :show-inheritance:

xbout.boutdataset module
------------------------

.. automodule:: xbout.boutdataset
    :members:
    :undoc-members:
    :show-inheritance:

xbout.load module
-----------------

.. automodule:: xbout.load
    :members:
    :undoc-members:
    :show-inheritance:

xbout.plotting.animate module
-----------------------------

.. automodule:: xbout.plotting.animate
    :members:
    :undoc-members:
    :show-inheritance:

xbout.plotting.utils module
---------------------------

.. automodule:: xbout.plotting.utils
    :members:
    :undoc-members:
    :show-inheritance:
